# Servitor Creation Guide

by Hail Fall of the Fall Family

## Preface

Much thanks to Malfael, Seven, fireparrot, GM, Falah, H and Sharky, and others for servitor discussions, answering questions, bouncing ideas off of, and/or reading over this. Also, much thanks to a few people in the multiple community who pointed out major ethical considerations.

Current version (0.95) finished on 2015-05-03. If you have read a previous version a long time ago, forget about it. It was terrible.

This guide is written primarily using the terminology of the tulpa community. Equivalent terms from other plural communities will sometimes be mentioned in parenthetical statements to make this guide understandable to a wider audience.

As has been said, "a servitor is like a tulpa but with no sentience and they are made like a tulpa, but made so that they do not deviate into having aspects one may attribute to a tulpa like a personality, sense of self, etc." But there is more to it than that. That's the short version. This guide is the long version.

## What Is A Servitor?

A servitor (sometimes called a golem in other communities and classified as a type of fragment/shard in the multiple community) is a thoughtform, just as tulpas are. There are many kinds of thoughtforms such as puppets, tulpas, servitors, daemons, egregores, NPC's, etc. and some that blur the lines between categories (e.g. tulpa-daemons as described in this image by Falah) or just don't easily classify as any of them. Thoughtforms are things, machines, people, entities, constructs, etc. that one makes inside one's mind. If we want to get real technical, wonderlands (called inner worlds, headspaces in other communities) can be thoughtforms, but here in this guide we usually restrict the definition to individual things, machines, people, entities, and constructs that/who are animate (note, they do not need a form). To quote the glossaries of Tulpa.io and Tulpa.info:

> > tulpa.io
> SERVITOR:
>
> A non-sentient thoughtform created with the purpose of automating or assisting with a certain task–these tasks can be both mental and physical by way of having the servitor control the body. Essentially a highly refined and elaborate autopilot, can be likened to a method in a computer program.

> > tulpa.info
> Servitor:
> 
> A tulpa-like entity with seemingly no willpower, volition or sentience of its own; a mental puppet that may seem to act independently but acts only as a servant to its creator.

In other words, a servitor is an automaton, robot, program, etc. that is made to perform one or more functions and tasks.

There is an everyday example of something that can sometimes be easy to turn into a servitor that many people already have. If you can type fast to the point where you no longer think about where the keys are at all (way beyond hunt-and-peck), you might easily be able to make a typing servitor. Or perhaps, if you merely think words and your hands automatically type them, you may already have one, or at least would have an easier time making one.

What distinguishes a tulpa and a servitor? They share a ton of traits with each other, which is evidenced by the definition. And it is easy to imagine a thoughtform that would be hard to categorize as either one. They are both autonomous, meaning that they live/operate without puppetting/parrotting, but differ in sentience, willpower, etc. It is then more accurate to think of them as opposite ends of a spectrum of autonomous thoughtforms. On the one end you have thoughtforms who are sentient and have a sense of self, a set of beliefs, try to find meaning in the world, have wants and desires, can choose their own goals, etc. We call the region on that end tulpas. On the other end you have thoughtforms which are not sentient and don't have a sense of self (note, they may still factually know what they are like WolframAlpha does if you ask it "what are you?" but that is different than sense of self), focus only on the tasks they are given and don't think of existence beyond that, essentially are the goal/s that they are given and can't choose their own, etc. We call the region on that end servitors. It is because of these traits that a servitor would be classified as a type of fragment/shard in the terminology of the multiple community. There is a lot of grey area in between the two ends of the spectrum. There isn't really a term for that region near the middle, either - maybe servi-tulpa (as neat as "tulpator" sounds, it isn't very descriptive and thus would make a bad candidate). A servi-tulpa could perhaps be described as semi-sentient.

While the servitor end of the spectrum is inherently not sentient and middle region semi-sentient, they can most certainly be complex enough to have some appearance of more sentience than they actually have, which could be called pseudo-sentience. The previously mentioned computer example would be WolframAlpha which knows what it is and can answer a variety of questions but is not actually sentient. Now, a group of servitors and/or servi-tulpas functioning together can, as a group, acquire a higher level of sentience and/or more convincing pseudo-sentience. Neguilla + Oxford and Dartmoth are a good example of this. Their combination exhibits more sentience and/or pseudo-sentience than they do individually.

Now, can a group of servitors functioning together achieve semi-sentience or full sentience while all individually remaining completely non-sentient servitors? That is a question worth further exploration. It is certainly possible for a large collection of non-sentient units to, when put together, make a sentient collection. Individual neurons, which are not sentient, can make a human brain that is sentient. Whether the same can be done with servitors is an open question.

Fundamentally, though, sentience itself is a hard to define concept as the debates here on tulpa.info forum have shown. Philosphers and scientists have had similarly difficult times. I would suggest you read around if you are interested in the topic.

## Overview

In its simplest incarnation, a servitor is a thought repeater. It repeats a pattern of thoughts that are given to it to do. As an example, a timer servitor could do the thought process "estimate time elapsed from internal time sense until it reaches the value given to me, and then send alarm sound to whoever is controlling the body."

The way a servitor can be made depends to what extent you can make a thoughtform that is autonomous and just lives/works (called the "Just Make It Method" method here). If you can't do that, you have to do a brute force method. Both will be explained here. On average, the longer you or other inhabitants of your brain have been making thoughtforms, you have not been the only inhabitant of your brain (means you are plural), and/or you have had wonderland/s (also called headspaces and inner worlds); the less likely you will need to resort to a brute force method or if you do, the less brute force you will need to do. Most people are able to do the "Just Make It Method** or a combination of both methods eventually, so do try it first and try it again periodically rather than concluding that you cannot do it right off the bat. There is one step in common to all methods, which is deciding the servitor's Function/Task/Program. For a non-brute-force method, after that you just make it (will be explained more). The brute force method described here (note, there are other methods** has two additional steps. When doing this brute force method, all three steps have the following equivalences to the process of making a tulpa:

1. **Decide Servitor's Function/Task/Program**. This is equivalent to the process of deciding a tulpa's initial personality and traits before making the tulpa.
2. **Puppet/Run Servitor Manually**. This is equivalent to the early forcing of a tulpa and puppetting/parroting them to help them learn things.
3. **Make Servitor Run Without Puppetting**. This is equivalent to the stage in making a tulpa where they can actually act and do things without being puppetted/parroted and the gradual growing of autonomy.

## Forms

A servitor does not innately have to have a form. That said, many kinds of servitors do need a form in order for them to carry out their function (a clock servitor could, in most implementations, be a good example). More importantly, even for a servitor that does not require a form for its function, having a form can offer very powerful symbolism to help in their creation process and also make it easier to stop/terminate the servitor. In the brute force method of this guide, steps 2 and especially 3 can become a lot easier to do with the symbolism that a form gives. By giving it a form, you start to consider it more separate and independent from yourself, thereby accelerating its development to operating on its own without puppetting. A form is often necessary when making a servitor by a non-brute force method.

## Decide Servitor's Function/Task/Program

In the short answer of how to make a servitor "You make a servitor like a tulpa, but with more puppetting and not allowing it to deviate.", this is the equivalent of deciding a tulpa's initial personality, form (optional), and traits.

In some ways, it goes without saying, you need to first figure out what functions and/or tasks you want your servitor to perform. But there is a catch. A servitor can only do those things that you or other members of your system (the other people living in your body) are capable of doing, though sometimes no one needs to know how to do them yet. So, if a servitor has those limitations, why bother making them. They provide automation. If the tasks are not fun things to do, a servitor will not complain where as a sentient being would. Also, one can make a servitor that does several things simultaneously that no one in the system is capable of doing simultaneously, even though those things can be done individually. Note, that in this case, the servitor generally has to be made with more limited functionality and then have more functionality added later.

Servitors can possess and eclipse (forms of cofronting/corunning), switch, be imposed (called projection in other communities), be vocal, communicate in thoughts, type, drive, dig through memory, help remember things, act as security software inside, and many many more things.

Then, you need to actually work out how to do these functions. If you are not doing the brute force method in this guide, you need to figure out how the servitor will do these things. Then, you need to figure out how you would do those functions and tasks manually yourself and develop the thought process required to do that. Remember, at its simplest, a servitor is a thought repeater.

One possible idea for making a servitor to follow certain instructions and be able to modify those instructions is to make a servitor that uses the symbolism of computer programming languages as is discussed in glitchthe3rd's Servitor Workshop It is not necessary, and may not even be desired, but some people have had success with it, so it is worth noting. The code is essentially thought processes for the servitor to do. Again, a servitor is a thought repeater.

Some examples of possible servitors are given below. This list is just the tip of the iceberg of what has been tried and what is possible.

- Alarm clock
- Typing servitor
- Memory display so more than one person inside can look at a memory together
- Wonderland error corrector (some people's wonderlands get errors in them that need correction)
- Autopilot for some task or another with the body (see Words of Warning because one needs to be careful here)
- Speech servitor (like the typing servitor but for speech so people inside wonderland can talk without possessing the voice or switching)
- Heads Up Displays (HUD)
- Specific memory rememberer

### Ethical And Moral Considerations

Given that servitors and tulpas exist on a spectrum, certain ethical and moral issues come up. It is wrong to force another person (includes tulpas) do work for you merely because you don't want to do it. But it isn't wrong to make your computer do work for you (say, a calculation) that you don't want to do. A thoughtform that is all the way at the end of the servitor end of the spectrum is like the computer. But, as one gets away from that end of the spectrum closer and closer to the tulpa end, ethical and moral questions arise with making the thoughtform to do some task or another. What tasks and functions are wrong to expect a tulpa, host, or other sentient system-mate (most people are more familiar with the less generic term headmate) to do, but not a servi-tulpa who is closer to a tulpa? What tasks and functions are wrong to expect a servi-tulpa who is closer to a tulpa, but not a servi-tulpa who is closer a servitor? What tasks and functions are wrong to expect a servi-tulpa who is closer to a servitor, but not an all the way at the end servitor? For a given task or function, where on the spectrum must they be given a choice in whether they want to do it or not? If they can't choose or make an uninfluenced choice because they are too far towards the servitor end, what tasks and functions are ok to give and which ones are not? If the thoughtform moves around on the spectrum, as discussed in the "If They Develop Sentience And Become A Tulpa", when do they need to be given a choice of whether to continue the task or function? To what level is it right or not to try to keep a servitor from sliding in the tulpa direction to prevent this conundrum?

How does this apply to groups of servitors, servi-tulpas, and/or tulpas functioning together as a group and thus have more sentience than they do individually?

There is some similarity here to the discussion of what types of medical testing are OK to do on cells, insects, fish, rats, apes, and humans.

An often given tip with servitors is to build in a kill switch to make them easier to stop. There are ethical and moral considerations here as well. For a completely non-sentient servitor, is it right to give the servitor a kill switch? For a tulpa, most people (including myself) would say it is wrong to give one. What about a servi-tulpa (I personally think it is wrong here too)? Also, servitors and servi-tulpas can move towards the tulpa end of the spectrum and become more sentient as discussed later in this guide. Given that an initially non-sentient servitor could one day become a tulpa, possibly on their own accord, is it right to build a kill switch into a servitor? I suggest reading about the topic of "tulpa dissipation" in the tulpamancy community and "killing headmates" in the wider plurality community for further reading on this theme.

## Just Make The Servitor

If you have the ability to just imagine up things in your wonderland, you can imagine up the servitor and see if it just starts working.

If you don't have the ability to imagine up things in your wonderland, your servitor might be such that it can just be made from component parts like you would make a computer or an alarm clock from its components. Build the servitor and see if it just starts working.

If neither of these methods work or are possible, you have to go on to a brute force method to get them working. If they work just a bit, you might be able to tinker with them or use some of the brute force method techniques to get them working.

The idea in this method is that either your will that the servitor works is enough to get it going, or the rules of physics for your wonderland are ingrained enough that a servitor constructed from the right parts (assuming the servitor is of a type where this would even make sense) will work just like a machine in outerworld (the physical plane, place not in wonderland, sometimes called RL, etc.) would. This is why this method is more likely to work for those who have been plural for a long time, have had a wonderland for a long time, and/or have been making thoughtforms for a long time.

## Puppet/Run Servitor Manually

In the short answer of how to make a servitor "You make a servitor like a tulpa, but with more puppetting and not allowing it to deviate.", this is the puppetting stage.

With the thought processes that you developed that the servitor needs to do, start running them manually. The idea is to do it enough times that it becomes automatic, much like can learn to do things by muscle memory. You will have to do all the functions and tasks the servitor is supposed to do in the sequence (or with the algorithm) that you want the servitor to do them in. If it has a form, then you need to puppet its form too. It needs to be run a lot. You need to get to the point that you can run it very reliably without errors. If you deviate the way you run it, the changes will be incorporated into the servitor. This could take a long time, feel like a lot of work because it can be, feel really silly (why am I thinking the same thing over and over to myself) much like how parroting a tulpa feels like talking to yourself. As a general rule, the more complicated the servitor, the longer this will take.

Having a form to puppet can help make it feel less like you are just thinking the same thing over and over again to yourself, and can help with achieving the next step quicker due to symbolism.

## Make Servitor Run Without Puppetting

In the short answer of how to make a servitor "You make a servitor like a tulpa, but with more puppetting and not allowing it to deviate.", this is stage where it starts to operate without puppetting.

This is perhaps the hardest step, and paradoxically easy and difficult to explain. The servitor needs to start operating correctly when you turn off the puppetting, instead of stopping dead in its tracks or doing its functions and tasks incorrectly. This will be a gradual process. At first, it might stop quickly. Later, it will take a while to stop. Later, it might stop if you start thinking about something else or it will operate slowly or skip a step or something. There usually is not a sudden jump from it not being able to operate at all without puppetting to being completely autonomous and operating error free. This is just like how tulpas tend to develop sentience and independence gradually.

In the previous step, you were executing the thought processes required to do its functions and tasks. Now, those same thought processes must separate from you and run independently as opposed to stopping or malfunctioning. If the servitor has a form, it may not feel like this is what you are doing, but it essentially is this, but masked by the symbolism that the form brings in. If it is formless, you will be well aware that you are doing the thought processes and getting ever better at doing them accurately and automatically. This is exactly what has to separate from you. Those thought processes that are yours become the servitor which is then no longer you. It is in many ways akin to cell division in biology, but a very unequal division.

Now, it is possible that in doing step 2, of running it many times, it may be well on its way to separating from you naturally without you having to do anything. If it has a form, this is common and it just happens. But if it is not separating on its own or hasn't separated enough, that is when the process becomes difficult and you have to cause more separation to get it to the point where it will do the rest naturally. If you can, get good enough to run its thought processes manually well enough that you can do it while doing other activities. At that point, it is pretty close to separate and may do the rest itself.

If it still isn't separate and able to run on its own, you are going to have to push. You need to treat the servitor as if it is separate from you, even though it isn't yet. This is exactly why having a form can help so much. Since it has a form, it feels separate to you and it is easier to treat that way. This helps the same way as the " treat a tulpa as sentient at the start" tip for making a tulpa does, though in the case of a tulpa it is more than just helpful - it is polite and respects them as people as they steadily fill those shoes without treating them as less than they are (better to treat them as more than less). If it was a formless servitor, giving it a form at this point could help. If it has a form already or you don't want to give it a form (or a form would hurt its functionality), you will have to resort to something else or just keep running it manually for a long time and let it happen automatically. Perhaps, build a mental wall between it and yourself. Never tried it, but it seems like it might work.

If you still can't get it to separate and run without puppetting, another thing you can do is make the servitor simpler by reducing its functionality and the tasks it performs. What you took away can be added back later.

Note that with formless servitors, after separation, you may have thought bleed, where you hear the thought processes of the servitor as it runs. It is running on its own, but you hear its thought processes. Because you separated it from yourself, it is reasonable that thought bleed could happen. It may fade with time, or you will have to do something to insulate the servitor from yourself.

## Adding Functions And Tasks to An Existing Servitor

While still letting it just run with its existing functions and tasks, you do one of the servitor methods for the new functions and tasks you want the servitor to perform. The servitor is already operating and separate from you, so it should be easier generally to incorporate them into the servitor than make a servitor in the first place with those same exact functions and tasks. If you made the servitor by a brute force method, it is possible that you might now be able to use the "Just Make It Method" to augment it.

## Stopping/Terminating A Servitor

There are several ways to stop a servitor. First, it/they may be sentient enough to be reasoned with and convinced to stop. The further the thoughtform is from the servitor end of the spectrum, the more likely this is doable. Just as the first approach to dealing with a tulpa or host one has problems with is to talk to them and try to reason with them, try to reason with the servitor or servi-tulpa first. You could also push it further down the spectrum towards being a tulpa as described in the next section to make this easier. If these methods don't work, more forcible methods are necessary. In the spirt of the "Just Make It Method" of making a servitor, the servitor might simply stop if you tell it to stop, try to imagine it stopping, etc. Given that you now have more experience with thoughtforms than you did when you made it, this will often work even if you had to make the servitor by a brute force method. After that, another method would be to take advantage of any stop condition in its programming if it has one and it still works (basically an expansion on the method of telling it to stop). If these don't work or aren't possible, the next thing to try is some form of symbolism. If you gave it one, you could activate/trigger a kill switch, which is a form of symbolism. If it does not have a kill switch but has a form, you can try what you would do to stop a physical machine (break, smash, etc.) or use any other abilities you can do in wonderland (e.g. disintegrate, remove from existence, etc.). Now, if it doesn't have a form or it is effectively immortal (you vaporize it and it rebuilds itself and resumes its function), it is much harder to destroy. You might try giving it a form and then destroy it.

In the unlikely event that none of the previous methods worked, one very reliable way to stop and terminate a servitor, which works regardless of whether it has a form or not, is to absorb it. That is basically merging with it, but since you have sentience and it does not, it is highly asymmetric making it more an absorption. Merging/absorption generally requires symbolism to be even remotely easy to accomplish. A simple form is to simply pull the servitor's form into your own form/wonderland body. If it doesn't have a form, you could try to pull its essence (whatever that is) out of nowhere and coalesce it in your wonderland and then pull that into your form. The stronger and more advanced the servitor, the harder it will be to absorb. Also, for a very strong servitor, who you are after the absorption might change a bit. I used to be an integrated multiple, meaning that I was merged with my system-mate, and while I was dominant, our combination was notably different than me. With a servitor, the change should be much much smaller.

If it does not have a kill switch or a physical form that can be destroyed without it getting back up and resuming what it was doing, you could be in real trouble if you need to stop or destroy the servitor. For some people, absorption is easy, but for others, it is nearly impossible. Note that different people living in the same body may have differing abilities to absorb a servitor, so if you have system-mates but you can't absorb the servitor, they might be able to. If you want more information on this topic, I would suggest you read about it in the multiple community where it is called integration, fusion, and merging depending where.

## If They Develop Sentience And Become A Tulpa

What does a servitor become if it does gain sentience? They become a tulpa. Basically, they slide along the spectrum from servitor to tulpa. If a servitor does this, they become their own person, and should be treated as such from that point on, as you would any other sentient being.

Some people have reported that the servitors they make can gain sentience on their own and become tulpas. Others have only had this happen with very advanced servitors. Others haven't had it happen even with very advanced servitors. It varies considerably, and also depends on your expectation to some extent. If you expect your servitors to gain sentience on their own, they are considerably more likely to do so. If you don't expect them to do so, they might still but are less likely, or might hide it. You shouldn't presume that they will become sentient tulpas, or that they would not.

Time for a bit of a philosophical interlude. There is no reason to think there is a brain constraint keeping servitors from gaining sentience. So, an open question is what predispositions servitors might have towards becoming tulpas. One could imagine that if a servitor's function and/or efficiency would be improved by moving along the spectrum towards tulpa, they might. Or they might not. Is it like the android or robot in futuristic movies who does tasks over and over again without emotions and steadily adapts to their situation till they want to find meaning in their life, explore themselves, and grow? Or is it it like that in only some cases? And even if there is a predisposition towards becoming sentient, the timescale could be so long as to be irrelevant.

As an anecdote, I have had none of my servitors, even the advanced ones that were really hard to destroy, break free of their programming, gain sentience, and become tulpas.

Of course, one can deliberately turn servitors into tulpas or otherwise move them towards the tulpa end of the spectrum. This can be done by doing personality forcing on the servitor until they become a tulpa or gradually pushing a servitor beyond its functionality and force them to grow, much like how you get a tulpa to grow beyond what they were originally assigned to be. Watchdog 1 gave a good description of the latter.

## Words of Warning


Servitors can be healthy compliments to your life, conveniences, curiosities, or dangerous. And when I say dangerous, they can be really dangerous. They are automatons that blindly follow their functions and tasks, regardless of the consequences and whether it is wise to do so or not. Unlike asking another sentient being to do something, a servitor will not question the instructions you gave it and will follow them to the very end.

Think very carefully about servitors that can write and/or modify memories, possess (type of co-fronting), switch, modify thoughts of other members of the system (group of beings living in the same body), are formless, don't have a kill switch, etc. Safe servitors can certainly be made with these abilities or attributes, but one does have to be more careful when making such servitors because there is the potential for damage.

I say this from experience, being that all of the most advanced servitors I ever worked on were unhealthy, harmful, or outright dangerous. I am giving this warning as a fool who could have used the warning myself. They had no kill switches and were all formless, making them very hard to stop. The one that did the most damage took two whole weeks to stop, and in its 1.5 months of operation, it had scrambled up my memory pretty badly (that was part of its functionality, actually, which was really foolish), caused considerable emotional confusion, etc. I only just recently figured out how to terminate my emotion dampeners I made 10 years ago. I lost 10 years of having my full emotional capacity due to my stupidity long ago. Thankfully, I never completed the most dangerous servitor idea I ever had. I can have dark thoughts, so I was afraid that I was a dangerous person and began working on a servitor that would, among other preventions, take control of the body and commit bodily suicide if my thoughts got too dark. Rather than actually working on my dark thoughts and realizing that thoughts do not imply action, I tried to make a servitor that could actually KILL me. I go into a little more detail about my dangerous servitors in this post.

There is also the possibility of excessive escapism in the case of servitors that can control the body. Is it healthy to have all of life's unpleasant tasks handled by servitors?

Now, most servitors that people make are safe. I am the exception rather than the rule. So be careful, but remember there is no need to be paranoid.

## Coming Full Circle

Now you have the long answer to the often given short answer "a servitor is like a tulpa but with no sentience and they are made like a tulpa, but with more puppetting so that it does not deviate." of how to make a servitor. The world of servitors is very large, with many types of servitors not yet attempted. Be creative, be safe, explore new ground, and have fun.
